==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/JavaHandler.h <==
// public class gnu.java.beans.decoder.JavaHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class 43bea19f89970324 gnu_java_beans_decoder_JavaHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_JavaHandler_H_
#define _JC_gnu_java_beans_decoder_JavaHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_DummyHandler$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$sub_refs	_jc_gnu_java_beans_decoder_JavaHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_JavaHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$refs	_jc_gnu_java_beans_decoder_JavaHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$nonrefs	_jc_gnu_java_beans_decoder_JavaHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$object	_jc_gnu_java_beans_decoder_JavaHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_JavaHandler$vmethods	_jc_gnu_java_beans_decoder_JavaHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_JavaHandler$vtable	_jc_gnu_java_beans_decoder_JavaHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_JavaHandler$vtype	_jc_gnu_java_beans_decoder_JavaHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_JavaHandler$method$_init$9f3d0fd1c26c2a16(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_gnu_java_beans_decoder_DummyHandler$object *, struct _jc_object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_JavaHandler$method$getObject$4d46b76f0c1f06c7(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_beans_decoder_JavaHandler$method$instantiateClass$3d29e0b0cdda5a0e(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_beans_decoder_JavaHandler$method$putObject$550ec55b7ef5c838(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_gnu_java_beans_decoder_JavaHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_gnu_java_beans_decoder_JavaHandler$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$getObject$4d46b76f0c1f06c7;
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$instantiateClass$3d29e0b0cdda5a0e;
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$putObject$550ec55b7ef5c838;
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$startElement$c132d696183c1bce;
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_JavaHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*getObject$4d46b76f0c1f06c7)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_Class$object	*(*instantiateClass$3d29e0b0cdda5a0e)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *);
	void	(*putObject$550ec55b7ef5c838)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_object *, struct _jc_object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_JavaHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_JavaHandler$vmethods	gnu_java_beans_decoder_JavaHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_JavaHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_JavaHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_JavaHandler$sub_refs {
	struct _jc_object	*context;
	struct _jc_java_util_HashMap$object	*objectMap;
	struct _jc_java_lang_ClassLoader$object	*classLoader;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_JavaHandler$refs {
    _jc_gnu_java_beans_decoder_JavaHandler$sub_refs	gnu_java_beans_decoder_JavaHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_JavaHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_JavaHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_JavaHandler$sub_nonrefs	gnu_java_beans_decoder_JavaHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_JavaHandler$object {
	_jc_gnu_java_beans_decoder_JavaHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_JavaHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_JavaHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_JavaHandler$vtype _jc_gnu_java_beans_decoder_JavaHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_JavaHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_JavaHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_JavaHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/JavaHandler.h <==
// public class gnu.java.beans.decoder.JavaHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class 43bea19f89970324 gnu_java_beans_decoder_JavaHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_JavaHandler_H_
#define _JC_gnu_java_beans_decoder_JavaHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_DummyHandler$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$sub_refs	_jc_gnu_java_beans_decoder_JavaHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_JavaHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$refs	_jc_gnu_java_beans_decoder_JavaHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$nonrefs	_jc_gnu_java_beans_decoder_JavaHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_JavaHandler$object	_jc_gnu_java_beans_decoder_JavaHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_JavaHandler$vmethods	_jc_gnu_java_beans_decoder_JavaHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_JavaHandler$vtable	_jc_gnu_java_beans_decoder_JavaHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_JavaHandler$vtype	_jc_gnu_java_beans_decoder_JavaHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_JavaHandler$method$_init$9f3d0fd1c26c2a16(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_gnu_java_beans_decoder_DummyHandler$object *, struct _jc_object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_JavaHandler$method$getObject$4d46b76f0c1f06c7(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_beans_decoder_JavaHandler$method$instantiateClass$3d29e0b0cdda5a0e(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_JavaHandler$method$putObject$550ec55b7ef5c838(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_beans_decoder_JavaHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_JavaHandler$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$getObject$4d46b76f0c1f06c7;
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$instantiateClass$3d29e0b0cdda5a0e;
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$putObject$550ec55b7ef5c838;
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$startElement$c132d696183c1bce;
extern _jc_method _jc_gnu_java_beans_decoder_JavaHandler$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_JavaHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*getObject$4d46b76f0c1f06c7)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*instantiateClass$3d29e0b0cdda5a0e)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*putObject$550ec55b7ef5c838)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_beans_decoder_JavaHandler$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_JavaHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_JavaHandler$vmethods	gnu_java_beans_decoder_JavaHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_JavaHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_JavaHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_JavaHandler$sub_refs {
	struct _jc_object	*context;
	struct _jc_java_util_HashMap$object	*objectMap;
	struct _jc_java_lang_ClassLoader$object	*classLoader;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_JavaHandler$refs {
    _jc_gnu_java_beans_decoder_JavaHandler$sub_refs	gnu_java_beans_decoder_JavaHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_JavaHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_JavaHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_JavaHandler$sub_nonrefs	gnu_java_beans_decoder_JavaHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_JavaHandler$object {
	_jc_gnu_java_beans_decoder_JavaHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_JavaHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_JavaHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_JavaHandler$vtype _jc_gnu_java_beans_decoder_JavaHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_JavaHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_JavaHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_JavaHandler_H_ */
